======================================================================
Simulation Environment for Atomistic and Molecular Simulations (SEAMM)
======================================================================

.. image:: https://img.shields.io/github/issues-pr-raw/molssi-seamm/seamm
   :target: https://github.com/molssi-seamm/seamm/pulls
   :alt: GitHub pull requests

.. image:: https://github.com/molssi-seamm/seamm/workflows/CI/badge.svg
   :target: https://github.com/molssi-seamm/seamm/actions
   :alt: Build Status

.. image:: https://codecov.io/gh/molssi-seamm/seamm/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/molssi-seamm/seamm
   :alt: Code Coverage

.. image:: https://github.com/molssi-seamm/seamm/workflows/CodeQL/badge.svg
   :target: https://github.com/molssi-seamm/seamm/security/code-scanning
   :alt: Code Quality

.. image:: https://github.com/molssi-seamm/seamm/workflows/Release/badge.svg
   :target: https://molssi-seamm.github.io/seamm/index.html
   :alt: Documentation Status

.. image:: https://img.shields.io/pypi/v/seamm.svg
   :target: https://pypi.python.org/pypi/seamm
   :alt: PyPi VERSION

.. image:: https://zenodo.org/badge/DOI/10.5281/zenodo.5153984.svg
   :target: https://doi.org/10.5281/zenodo.5153984
   :alt: DOI

The MolSSI Simulation Environment for computational molecular and materials science (CMS)


* Free software: GNU Lesser General Public License v3
* Documentation: https://molssi-seamm.github.io/seamm/index.html


Features
--------

* TODO

Credits
-------

This package was created with Cookiecutter_ and the `molssi-seamm/cookiecutter-seamm-plugin`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`molssi-seamm/cookiecutter-seamm-plugin`: https://github.com/molssi-seamm/cookiecutter-seamm-plugin

Developed by the Molecular Sciences Software Institute (MolSSI_),
which receives funding from the `National Science Foundation`_ under
awards OAC-1547580 and CHE-2136142

.. _MolSSI: https://www.molssi.org
.. _`National Science Foundation`: https://www.nsf.gov
